<?php

namespace Ems\Services;

use Ems\Repository\{ EquipeRepository, PeriodoRepository };
use GuzzleHttp\Client;

class EnderecoService {
    /** @var Client */
    protected $client;

    protected const CEP_API_URL = 'http://api.postmon.com.br/';
    protected const CEP_API_URI = 'cep';

    public function __construct(
    ) {
        $this->client = new Client([
            'base_uri' => self::CEP_API_URL
        ]);
    }

    public function pesquisarCep(
        string $cep
    ): array {
        $status = [
            'success' => true,
            'message' => null,
            'cepInfo'    => null
        ];

        $cepIsValid = self::validaCep($cep);

        if (!$cepIsValid) {
            $status['success'] = false;
            $status['message'] = 'CEP inválido!';

            return $status;
        }

        $cep = self::onlyNumbers($cep);

        $url = self::CEP_API_URI . '/' . $cep;

        $response = $this->client->get($url);

        $content = $response->getBody()->getContents();
        $body = json_decode($content, true);

        $status['cepInfo'] = $body;

        return $status;
    }

    public static function validaCep(
        string $cep
    ): bool {
        $isValid = preg_match('^\d{2}.?\d{3}-?\d{3}$^', $cep) === 1;
        return $isValid;
    }

    public static function onlyNumbers(
        string $text
    ): string {
        preg_match_all('!\d+!', $text, $matches);
        $numbers = implode('', $matches[0]);

        return $numbers;
    }
}